@@ -7,60 +7,68 @@ import os
 import sys
 # ----- port here. 5000 is flask; is moved to 8000 by gunicorn; to 80 by nginx
 CONFIG={  'filename':'~/.config/test/cfg.json',
-          'recommended':"",
+          #'recommended':"",
 
           'product':"",
           'resolution':"640x480",
           'framekind':"direct",
-          'laps':0,
-          'web5000':False,
-          'mmaga':'def',
-          'save':False,
-          'qpassfile':"~/.pycamfw_userpass",
-          'otate':0, # rotate 0
-          'zoom':1,
-          'vof':110, # field of view 110 degrees default (uniwrec only)
-
-          'user':'aaa',
-          'password':'aaa',
-          'zmqtarget':'127.0.0.1',
-          # ------------------  things for DM ----------
-          # DEPREC target_frame  for framekind
-          'target_frame':'direct',
           'average':0,
           'threshold':0,
           'blur':0,
-          # DEPREC TIMELAPS for laps
-          'timelaps':3600,
-          'histogram':False,
-          # ----------------------
-          # ------------------ ASTRO speed compensation
-          'x':0,
-          'y':0 ,
-          # DEPRAC ROTATE180 for otate
-          'rotate180':False,
-          # ------------------------
+          'laps':0,
+          'web5000':False,
           'expo':'auto',
           # DEPRAC GAMMA for mmaga
-          'gamma':'def',
+          #'gamma':'def',
           'gain':'def',
+          'mmaga':'def',
+          'histogram':False,
+          # 'zmqtarget':'127.0.0.1',
+          'imagezmq':None,
+          'jtelegram':False,
           'kompress':95,
+          'save':False,
+
+          'qpassfile':"~/.pycamfw_userpass",
+
+          'otate':0, # rotate 0
+          'x':0,
+          'y':0,
+
+          'vof':110, # field of view 110 degrees default (uniwrec only)
+          'zoom':1,
+
+
+          'user':'aaa',
+          'password':'aaa',
+          # ------------------  things for DM ----------
+          # DEPREC target_frame  for framekind
+          #'target_frame':'direct',
+          # DEPREC TIMELAPS for laps
+          #'timelaps':3600,
+          # ----------------------
+          # ------------------ ASTRO speed compensation
+          # DEPRAC ROTATE180 for otate
+          #'rotate180':False,
+          # ------------------------
           #-----------------------
-#          'camera_on':False,   # quewstionable...
-          'interpolation':'None',
-          'mintime':0.1,       # normal picture rate
-          'videodev':0,
+          #          'camera_on':False,   # quewstionable...
+          #'interpolation':'None',
+          #'mintime':0.1,       # normal picture rate
+          #'videodev':0,
           'port':5000,
-          'change':None,
-          'autoiris':True,
-          'riris':1000,
-          'pantilt':False,
-          'pan':0,
-          'tilt':0,
-          'gamma_adjust':False,
-          'rgain':0,
-          'use_v4l':True,      # zdenek84 had a problem with. I try again
-          'quit':False         # this is howto quit
+          #'change':None,
+          #'autoiris':True,
+          #'riris':1000,
+          #'pantilt':False,
+          #'pan':0,
+          #'tilt':0,
+          #'gamma_adjust':False,
+          #'rgain':0,
+          #'use_v4l':True,      # zdenek84 had a problem with. I try again
+          #'quit':False         # this is howto quit
+          #------ end with nothing
+          'placeholder':False
 
 }
 
@@ -250,6 +258,7 @@ def load_config(filename=""):
 
 
     CONFIG = dicti
+    return True
     #if CFG_DEBUG:
     #print("D... final CONFIG:")
     #show_config(filename)
