@@ -6,7 +6,7 @@ from flashcam.base_camera2 import BaseCamera
 from flashcam.usbcheck import recommend_video
 # import base_camera  #  Switches: slowrate....
 
-import datetime
+import datetime as dt
 import time
 import socket
 
@@ -109,10 +109,24 @@ class Camera(BaseCamera):
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
-        try:
+
+        senh.zmqtarget = None # initially
+        if 'imagezmq' in config.CONFIG:
             senh.zmqtarget = config.CONFIG['imagezmq']
-        except:
-            print("!... neet to update config for imagezmq")
+            if senh.zmqtarget=="None":
+                senh.zmqtarget = None
+        else:
+            print("X... need to update config for imagezmq")
+            senh.zmqtarget = None
+
+        if 'jtelegram' in config.CONFIG:
+            senh.jtelegram = config.CONFIG['jtelegram']
+            if senh.jtelegram=="false":
+                senh.jtelegram = False
+        else:
+            print("X... need to update config for imagezmq")
+            senh.jtelegram = False
+
 
         # === I must have these GLOBAL and PREDEFINED HERE <= web.py
         # --------------------------------  control
@@ -133,9 +147,10 @@ class Camera(BaseCamera):
 
         MODE_DMbase = "MODE DM"
         MODE_DM = "MODE DM"
-        imagezmq = None
-        if 'imagezmq' in config.CONFIG:
-            imagezmq     = config.CONFIG['imagezmq']
+
+        #imagezmq = None # I use senh.zmqtarget....
+        #if 'imagezmq' in config.CONFIG:
+        #    imagezmq     = config.CONFIG['imagezmq']
 
         print( "XY: ", config.CONFIG['x'] ,  config.CONFIG['y']  , speedx, speedy)
 
@@ -149,7 +164,7 @@ class Camera(BaseCamera):
         save_foreground = False
 
         send_telegram = None # i hope this is ok too...
-        telegramlast = datetime.datetime.now()
+        telegramlast = dt.datetime.now()
 
         restart_translate = False
 
@@ -212,11 +227,13 @@ class Camera(BaseCamera):
 
 
             if (vidnum is None) or (vidnum==-1):
-                print(f"!... no VID recommended, I'm in a loop (realcam/frames) {datetime.datetime.now().strftime('%H:%M:%S')}", end = "\r")
+                print(f"!... no VID recommended, I'm in a loop (realcam/frames) {dt.datetime.now().strftime('%H:%M:%S')}", end = "\r")
 
                 #print(fullpath_fixed_image)
                 # fullpath_fixed_image = "~/.config/flashcam/monoskop.jpg"
 
+                # special treatment for fixed image/screenshot.jpg...
+
                 if os.path.exists(fullpath_fixed_image):
                     frame = cv2.imread( fullpath_fixed_image)
                     #print(f"i...  {fullpath_fixed_image}")
@@ -461,17 +478,23 @@ class Camera(BaseCamera):
                         print("X... EXEC FAIL",expression,value)
 
 
+                    # THIs - I think - Is for send telegram via web interface
+                    # it is rather DEBUG tool than a real use
+                    # NOT TESTED
+                    #senh.telegram_send_image()
 
-                    telegramnow = datetime.datetime.now()
-                    if not (send_telegram is None):
-                        # telegram
-                        if os.path.exists(os.path.expanduser("~/.telegram.token")):
-                            if (telegramnow-telegramlast).total_seconds()>10:
-                                y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"{send_telegram} {telegramnow.strftime('%a %H:%M:%S')}",frame) )
-                                y.start()
+                    # telegramnow = dt.datetime.now()
+                    # if not (send_telegram is None):
+                    #     # telegram
+                    #     if os.path.exists(os.path.expanduser("~/.telegram.token")):
+                    #         if (telegramnow-telegramlast).total_seconds()>10:
+                    #             y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"{send_telegram} {telegramnow.strftime('%a %H:%M:%S')}",frame) )
+                    #             y.start()
 
-                                telegramlast=telegramnow
-                                send_telegram = None
+                    #             telegramlast=telegramnow
+                    #             send_telegram = None
+                    #     else:
+                    #         print("X... telegram requested, token not found")
 
 
                     if save_background:
@@ -693,21 +716,37 @@ class Camera(BaseCamera):
                     #         senh.setbox(f"m {gamma}",  senh.gamma)
 
 
-                    # ----  for detmo ---- work with detect motion--------------------
+
+                    # delayed telegram - preset in DM ========================
+
+                    if not(type(senh.telegramtrigger))==bool:
+                        if dt.datetime.now()>senh.telegramtrigger:
+                            print("i... telegram time tripped...", senh.telegramtrigger.strftime("%H:%M:%S"), "NOW=",dt.datetime.now().strftime("%H:%M:%S") )
+                            senh.telegramtrigger = False
+                            senh.telegram_send_image()
+
+
+                    # ----  for DetMo ---- work with detect motion----------------
+                    #   telegram and imagezmq are active only here
                     if (threshold>0) :
                         # here there was MODE DM.
                         # but with imageZMQ and Telegram ALERT....
                         #
-                        if not imagezmq is None:
+                        if not senh.zmqtarget is None:
                             MODE_DM=MODE_DMbase+"z"
-                            if os.path.exists(os.path.expanduser("~/.telegram.token")):
+                            if senh.jtelegram:
                                 MODE_DM=MODE_DM+"T"
+                        elif (senh.jtelegram):
+                            MODE_DM=MODE_DMbase+"T"
+
                         senh.setbox(MODE_DM, senh.MODE) #---push UP to avoid DetMot
+                        print("D... detecting motion")
                         senh.detmo( average, blur)
                         senh.chk_threshold( threshold )
                         if senh.motion_detected: # saving avi on mation detect
                             # print("D... sav mot", senh.motion_detected)
                             senh.save_avi( seconds = -1, name = "dm" )
+
                     else:
                         senh.setaccum( average  )
                         senh.setblur( blur )
