@@ -97,10 +97,14 @@ class Stream_Enhancer:
     FGFILE = os.path.expanduser('~/.config/flashcam/foreground.jpg')
 
     zmqrpi_name = socket.gethostname()
-    zmqtarget = None
-    zmqsender = None
+    zmqtarget = None #IP is operated from real_camera
+    zmqsender = None # object
     zmqlast = dt.datetime.now()
+
+    jtelegram = False # connector from real_camera
     telegramlast = dt.datetime.now()
+    telegramdelay = 2 #  send 2 sec later after the triger...
+    telegramtrigger = False ## either BOOL or DATETIME
 
 
     def RC_COLOR(self,row,col):
@@ -794,63 +798,103 @@ class Stream_Enhancer:
         self.histo_frame = h
 
 
+    def zmqsender_send_image(self):
+        """
+        just send, but catch exception....
+        """
+        try:
+            self.zmqsender.send_image( self.zmqrpi_name, self.frame )
+            print(f"i... zmq was sent to {self.zmqtarget}")
+        except:
+            print(f"i... zmq NOT sent to {self.zmqtarget}")
+            self.zmqsender = None
+        return
+
+
+    def telegram_send_image(self):
+        """
+        send telegram from here... be sure:no flooding
+        """
+        # telegram
+        TELEGRAMBLOCK = 300 # seconds
+        if self.jtelegram and (os.path.exists(os.path.expanduser("~/.telegram.token"))):
+            telegramnow = dt.datetime.now()
+            # 5 minutes
+            # protection against flooding
+            if (telegramnow-self.telegramlast).total_seconds()>TELEGRAMBLOCK:
+                print(f"fCAMERA {self.zmqrpi_name} ")
+                print(f"fCAMERA {self.zmqrpi_name} {telegramnow.strftime('%a %H:%M:%S')}")
+                y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"CAMERA {self.zmqrpi_name} {telegramnow.strftime('%a %H:%M:%S')}", self.frame))
+                y.start()
+                print("i.. telegram SENT============")
+                self.telegramlast=telegramnow
+            else:
+                print("i.. telegram not allowed due time", (telegramnow-self.telegramlast).total_seconds())
+        else:
+            print(f"X...  jtele=={self.jtelegram}, token")
+        return
+
 
 
 # --------------------------------------------------------save avi ------------
+# ------------------------------------------------- also ZMQ
     def save_avi(self, seconds =  1, name = "" ):
         """
-        seconds for timelaps  ;   -1 with name="dm" for detectmotion
+        seconds>0 for TIMELAPS  ;   -1 with name="dm" for detectmotion
         """
         #print("i... save_avi", seconds, name)
         # -------------- one shot
+
         if seconds == 0:
             return
         elif seconds<0: # - means saving avi - motion detect or in uni...
+
+            # trigger is old now
+            # if not(self.telegramtrigger)==bool:
+            #     if self.telegramtrigger<=dt.datetime.now()+dt.timedelta(seconds=1):
+            #         self.telegramtrigger = dt.datetime.now()+dt.timedelta(seconds=2)
+            #         print(f"i... telegram preset to {self.telegramtrigger.strftime('%H:%M:%S')}")
+
             if not self.aviopened:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}{name}_{filename}.avi"
                 filename = os.path.expanduser("~/DATA/"+filename)
-                print(filename)
-                print(filename)
-                print(filename)
-                print(filename)
+                for i in range(3): print(filename)
 
-                print("!... getting zmq sender:", self.zmqtarget)
-                if not self.zmqtarget is None:
-                    self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
-                    self.zmqsender.zmq_socket.setsockopt(zmq.LINGER, 0)  # prevents ZMQ hang on exit
-                    # NOTE: because of the way PyZMQ and imageZMQ are implemented, the
-                    #       timeout values specified must be integer constants, not variables.
-                    #       The timeout value is in milliseconds, e.g., 2000 = 2 seconds.
-                    self.zmqsender.zmq_socket.setsockopt(zmq.RCVTIMEO, 2000)  # set a receive timeout
-                    self.zmqsender.zmq_socket.setsockopt(zmq.SNDTIMEO, 2000)  # set a send timeout
-                    print("!... got it", self.zmqsender)
 
+                #--- what happens if not 640x480 and xvid?
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout = cv2.VideoWriter( filename , fourcc , 25.0, (640,480))
                 self.aviopened = True
 
             elif (self.aviopened) and ( (dt.datetime.now()-self.avi_started).total_seconds()>86400): # it is opened but too long, one day....
                 self.aviout.release()
-                filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
-                filename = f"{me}{name}_{filename}.avi"
-                filename = os.path.expanduser("~/DATA/"+filename)
-                print(filename)
-                print(filename)
-                print(filename)
-                print(filename)
+                filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
+                filename = os.path.expanduser("~/DATA/"+f"{me}{name}_{filename}.avi")
+                for i in range(3): print(filename)
                 self.aviopened = True
-                self.avi_started = dt.datetime.now()  #
+                self.avi_started = dt.datetime.now()
 
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout = cv2.VideoWriter( filename , fourcc , 25.0, (640,480))
 
             self.aviout.write(self.frame)
+            # plan telegram send to future
+            if type(self.telegramtrigger)==bool:
+                self.telegramtrigger = dt.datetime.now()+dt.timedelta(seconds=2)
+                print("i... telegramtrigger preset to +2 sec.",self.telegramtrigger.strftime("%H:%M:%S"))
+            # MOMENT WHEN AVI IS SAVED===========> imagezmq, telegram...
 
 
-            if  (self.zmqsender is None) and (not self.zmqtarget is None):
+
+
+            #print(self.zmqsender,self.zmqtarget)
+            # zmqtarget - if not NONE not initialized
+            if  (self.zmqsender is None) and not (self.zmqtarget is None):
+                print(self.zmqsender,self.zmqtarget," INITIALIZING",f'tcp://{self.zmqtarget}:5555')
+
                 self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
                 self.zmqsender.zmq_socket.setsockopt(zmq.LINGER, 0)  # prevents ZMQ hang on exit
                 # NOTE: because of the way PyZMQ and imageZMQ are implemented, the
@@ -860,36 +904,31 @@ class Stream_Enhancer:
                 self.zmqsender.zmq_socket.setsockopt(zmq.SNDTIMEO, 2000)  # set a send timeout
 
 
-            if not self.zmqsender is None:
-                zmqnow = dt.datetime.now()
-                telegramnow = zmqnow
 
-                # telegram
-                if os.path.exists(os.path.expanduser("~/.telegram.token")):
-                    if (telegramnow-self.telegramlast).total_seconds()>300:
-                        y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"CAMERA {self.zmqrpi_name} {zmqnow.strftime('%a %H:%M:%S')}", self.frame))
-                        y.start()
-                        self.telegramlast=telegramnow
+
+            # if zmqtarget IP address is given:
+            if not(self.zmqtarget is None) and not(self.zmqsender is None):
+                #print(self.zmqsender,self.zmqtarget," action")
+                zmqnow = dt.datetime.now()
+
 
                 # imagezmq
                 if (zmqnow-self.zmqlast).total_seconds()>1.5:
-                    x = threading.Thread(target=self.zmqsender.send_image, args=(self.zmqrpi_name, self.frame))
+                    #x = threading.Thread(target=self.zmqsender.send_image, args=(self.zmqrpi_name, self.frame))
+                    x = threading.Thread(target=self.zmqsender_send_image ) # i will try to catch exceptions...
                     x.start()
                     #self.zmqsender.send_image(self.zmqrpi_name, self.frame)
                     self.zmqlast=zmqnow
-                    print(f"i... zmq is being sent to {self.zmqtarget}")
+
+
 
         # -------------- timelapse if seconds>0:
         elif seconds>0:
             if not self.aviopened_laps:
-                filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
-                filename = f"{me}_laps{seconds:04d}_{filename}.avi"
-                filename = os.path.expanduser("~/DATA/"+filename)
-                print(filename)
-                print(filename)
-                print(filename)
-                print(filename)
+                filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
+                filename = os.path.expanduser("~/DATA/"+ f"{me}_laps{seconds:04d}_{filename}.avi" )
+                for i in range(3): print(filename)
 
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout_laps = cv2.VideoWriter( filename , fourcc , 10.0, (640,480))
