@@ -265,6 +265,10 @@ def recommend_video( prefname=None ):
     """
     usb_hubs = usbroot()
 
+
+    if not(prefname is None) and  prefname.find(".jpg")>=0:
+        return [-1] # if image is required
+
     devices=serial.tools.list_ports.comports()
     print("____________________serial  devices _______"+"_"*37)
     for i in devices:
@@ -301,7 +305,7 @@ def recommend_video( prefname=None ):
                 id_path = ":".join( id_path.split(":")[2:] )
                 ok = True
             except  Exception as ex:
-                print("X... udevadm error...", ex, vid)
+                print("X... udevadm error...", ex, vid, end="\r")
                 ok = False
 
             if ok:
