@@ -7,16 +7,26 @@ This is flask interface
 '''
 from flashcam.version import __version__
 from fire import Fire
-
+import sys
 from flashcam import config
+
 config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-config.load_config()
+if not config.load_config():
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXx")
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXx")
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXx")
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXx")
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXx")
+    sys.exit(1)
 print("---------------------------------------- LOADED IN WEBPY")
 print(config.CONFIG)
 print(config.CONFIG["histogram"], "==histo in web")
 # print("------------JUST LOADED---------------")
 
 
+
+
+
 from importlib import import_module
 import os
 import sys  #exit
